@@ -105,7 +105,7 @@ namespace Binc {
       unsigned char c = *i;
       unsigned char d = *(i + 1);
       
-      char *t;
+      const char *t;
       if ((t = strchr(hexchars, c)) == 0)
 	return "out of range";
       n = (t - hexchars) << 4;
