@@ -55,6 +55,44 @@ using namespace std;
 #define MAX(A,B) (((A)>(B)) ? (A) : (B))
 #endif
 
+bool ParamStale::needrecompute()
+{
+    if (parent->m_keydirgen != savedkeydirgen) {
+        savedkeydirgen = parent->m_keydirgen;
+        string newvalue;
+        if (!conffile)
+            return false;
+        conffile->get(paramname, newvalue, parent->m_keydir);
+        if (newvalue.compare(savedvalue)) {
+            savedvalue = newvalue;
+            return true;
+        }
+    }
+    return false;
+}
+void ParamStale::init(RclConfig *rconf, ConfNull *cnf, const string& nm)
+{
+    parent = rconf;
+    conffile = cnf;
+    paramname = nm;
+    savedkeydirgen = -1;
+}
+
+void RclConfig::zeroMe() {
+    m_ok = false; 
+    m_keydirgen = 0;
+    m_conf = 0; 
+    mimemap = 0; 
+    mimeconf = 0; 
+    mimeview = 0; 
+    m_fields = 0;
+    m_stopsuffixes = 0;
+    m_maxsufflen = 0;
+    m_stpsuffstate.init(this, 0, "recoll_noindex");
+    m_skpnstate.init(this, 0, "skippedNames");
+    m_rmtstate.init(this, 0, "indexedmimetypes");
+}
+
 RclConfig::RclConfig(const string *argcnf)
 {
     zeroMe();
@@ -95,7 +133,7 @@ RclConfig::RclConfig(const string *argcnf)
 	// creating indexes all over the place
 	string conffile = path_cat(m_confdir, "recoll.conf");
 	if (access(conffile.c_str(), 0) < 0) {
-	    m_reason = "Explicitely specified configuration must exist"
+	    m_reason = "Explicitly specified configuration must exist"
 		" (won't be automatically created)";
 	    return;
 	}
@@ -134,6 +172,10 @@ RclConfig::RclConfig(const string *argcnf)
 
     m_ok = true;
     setKeyDir("");
+
+    m_stpsuffstate.init(this, mimemap, "recoll_noindex");
+    m_skpnstate.init(this, m_conf, "skippedNames");
+    m_rmtstate.init(this, m_conf, "indexedmimetypes");
     return;
 }
 
@@ -145,6 +187,8 @@ bool RclConfig::updateMainConfig()
 	stringsToString(m_cdirs, where);
 	m_reason = string("No/bad main configuration file in: ") + where;
 	m_ok = false;
+        m_skpnstate.init(this, 0, "skippedNames");
+        m_rmtstate.init(this, 0, "indexedmimetypes");
 	return false;
     }
     setKeyDir("");
@@ -159,6 +203,8 @@ bool RclConfig::updateMainConfig()
 	    TextSplit::cjkProcessing(true);
 	}
     }
+    m_skpnstate.init(this, m_conf, "skippedNames");
+    m_rmtstate.init(this, m_conf, "indexedmimetypes");
     return true;
 }
 
@@ -176,6 +222,10 @@ ConfNull *RclConfig::cloneMainConfig()
 // prefetch a few common values.
 void RclConfig::setKeyDir(const string &dir) 
 {
+    if (!dir.compare(m_keydir))
+        return;
+
+    m_keydirgen++;
     m_keydir = dir;
     if (m_conf == 0)
 	return;
@@ -184,21 +234,6 @@ void RclConfig::setKeyDir(const string &dir)
 	defcharset.erase();
 
     getConfParam("guesscharset", &guesscharset);
-
-    string rmtstr;
-    if (m_conf->get("indexedmimetypes", rmtstr, m_keydir)) {
-	stringtolower(rmtstr);
-	if (rmtstr != m_rmtstr) {
-	    LOGDEB2(("RclConfig::setKeyDir: rmtstr [%s]\n", rmtstr.c_str()));
-	    m_rmtstr = rmtstr;
-	    list<string> l;
-	    // Yea, no good to go string->list->set. Lazy me.
-	    stringToStrings(rmtstr, l);
-	    for (list<string>::iterator it = l.begin(); it !=l.end(); it++) {
-		m_restrictMTypes.insert(*it);
-	    }
-	}
-    }
 }
 
 bool RclConfig::getConfParam(const std::string &name, int *ivp)
@@ -250,15 +285,17 @@ list<string> RclConfig::getTopdirs()
 
 // Get charset to be used for transcoding to utf-8 if unspecified by doc
 // For document contents:
-//   If defcharset was set (from the config or a previous call), use it.
-//   Else, try to guess it from the locale
-//   Use iso8859-1 as ultimate default
-//   defcharset is reset on setKeyDir()
+//  If defcharset was set (from the config or a previous call, this
+//   is done in setKeydir), use it.
+//  Else, try to guess it from the locale
+//  Use iso8859-1 as ultimate default
+//
 // For filenames, same thing except that we do not use the config file value
 // (only the locale).
 const string& RclConfig::getDefCharset(bool filename) 
 {
-    static string localecharset; // This supposedly never changes
+    // This can't change once computed inside a process.
+    static string localecharset; 
     if (localecharset.empty()) {
 	const char *cp;
 	cp = nl_langinfo(CODESET);
@@ -301,7 +338,6 @@ std::list<string> RclConfig::getAllMimeTypes()
     std::list<string> lst;
     if (mimeconf == 0)
 	return lst;
-    //    mimeconf->sortwalk(mtypesWalker, &lst);
     lst = mimeconf->getNames("index");
     lst.sort();
     lst.unique();
@@ -349,24 +385,20 @@ typedef multiset<SfString, SuffCmp> SuffixStore;
 
 bool RclConfig::inStopSuffixes(const string& fni)
 {
-    if (m_stopsuffixes == 0) {
+    if (m_stopsuffixes == 0 || m_stpsuffstate.needrecompute()) {
 	// Need to initialize the suffixes
+        delete STOPSUFFIXES;
 	if ((m_stopsuffixes = new SuffixStore) == 0) {
 	    LOGERR(("RclConfig::inStopSuffixes: out of memory\n"));
 	    return false;
 	}
-	string stp;
 	list<string> stoplist;
-	if (mimemap && mimemap->get("recoll_noindex", stp, m_keydir)) {
-	    stringToStrings(stp, stoplist);
-	}
+        stringToStrings(m_stpsuffstate.savedvalue, stoplist);
 	for (list<string>::const_iterator it = stoplist.begin(); 
 	     it != stoplist.end(); it++) {
-	    string lower(*it);
-	    stringtolower(lower);
-	    STOPSUFFIXES->insert(SfString(lower));
-	    if (m_maxsufflen < lower.length())
-		m_maxsufflen = lower.length();
+	    STOPSUFFIXES->insert(SfString(stringtolower(*it)));
+	    if (m_maxsufflen < it->length())
+		m_maxsufflen = it->length();
 	}
     }
 
@@ -386,7 +418,7 @@ bool RclConfig::inStopSuffixes(const string& fni)
     }
 }
 
-string RclConfig::getMimeTypeFromSuffix(const string &suff)
+string RclConfig::getMimeTypeFromSuffix(const string& suff)
 {
     string mtype;
     mimemap->get(suff, mtype, m_keydir);
@@ -444,9 +476,14 @@ bool RclConfig::getMimeCatTypes(const string& cat, list<string>& tps)
 string RclConfig::getMimeHandlerDef(const std::string &mtype, bool filtertypes)
 {
     string hs;
+    if (filtertypes && m_rmtstate.needrecompute()) {
+        m_restrictMTypes.clear();
+        stringToStrings(stringtolower((const string&)m_rmtstate.savedvalue), 
+                        m_restrictMTypes);
+    }
     if (filtertypes && !m_restrictMTypes.empty()) {
 	string mt = mtype;
-	stringtolower(mt);
+        stringtolower(mt);
 	if (m_restrictMTypes.find(mt) == m_restrictMTypes.end())
 	    return hs;
     }
@@ -455,6 +492,33 @@ string RclConfig::getMimeHandlerDef(const std::string &mtype, bool filtertypes)
     }
     return hs;
 }
+
+/** 
+ * @param whole is like "base value ; attr1 = somthing; attr2 = somethelse"
+ * There is no way to escape a semi-colon inside whole
+ */
+bool RclConfig::valueSplitAttributes(const string& whole, string& value, 
+                              ConfSimple& attrs)
+{
+    string::size_type semicol0 = whole.find_first_of(";");
+    value = whole.substr(0, semicol0);
+    string attrstr;
+    if (semicol0 != string::npos && semicol0 < whole.size() - 1) {
+        attrstr = whole.substr(semicol0+1);
+    }
+
+    // Handle additional attributes. We substitute the semi-colons
+    // with newlines and use a ConfSimple
+    if (!attrstr.empty()) {
+        for (string::size_type i = 0; i < attrstr.size(); i++)
+            if (attrstr[i] == ';')
+                attrstr[i] = '\n';
+        attrs = ConfSimple(attrstr);
+    }
+    return true;
+}
+
+
 string RclConfig::getMissingHelperDesc()
 {
     string fmiss = path_cat(getConfDir(), "missing");
@@ -462,6 +526,7 @@ string RclConfig::getMissingHelperDesc()
     file_to_string(fmiss, out);
     return out;
 }
+
 void RclConfig::storeMissingHelperDesc(const string &s)
 {
     string fmiss = path_cat(getConfDir(), "missing");
@@ -611,10 +676,14 @@ string RclConfig::fieldCanon(const string& f)
     return fld;
 }
 
-string RclConfig::getMimeViewerDef(const string &mtype)
+string RclConfig::getMimeViewerDef(const string &mtype, const string& apptag)
 {
+    LOGDEB(("RclConfig::getMimeViewerDef: mtype %s apptag %s\n",
+            mtype.c_str(), apptag.c_str()));
     string hs;
-    mimeview->get(mtype, hs, "view");
+    if (apptag.empty() || !mimeview->get(mtype + string("|") + apptag,
+                                         hs, "view"))
+        mimeview->get(mtype, hs, "view");
     return hs;
 }
 
@@ -624,7 +693,7 @@ bool RclConfig::getMimeViewerDefs(vector<pair<string, string> >& defs)
 	return false;
     list<string>tps = mimeview->getNames("view");
     for (list<string>::const_iterator it = tps.begin(); it != tps.end();it++) {
-	defs.push_back(pair<string, string>(*it, getMimeViewerDef(*it)));
+	defs.push_back(pair<string, string>(*it, getMimeViewerDef(*it, "")));
     }
     return true;
 }
@@ -705,14 +774,12 @@ string RclConfig::getStopfile()
     return path_cat(getConfDir(), "stoplist.txt");
 }
 
-list<string> RclConfig::getSkippedNames()
+list<string>& RclConfig::getSkippedNames()
 {
-    list<string> skpl;
-    string skipped;
-    if (getConfParam("skippedNames", skipped)) {
-	stringToStrings(skipped, skpl);
+    if (m_skpnstate.needrecompute()) {
+	stringToStrings(m_skpnstate.savedvalue, m_skpnlist);
     }
-    return skpl;
+    return m_skpnlist;
 }
 
 list<string> RclConfig::getSkippedPaths()
@@ -722,7 +789,9 @@ list<string> RclConfig::getSkippedPaths()
     if (getConfParam("skippedPaths", skipped)) {
 	stringToStrings(skipped, skpl);
     }
-    // Always add the dbdir and confdir to the skipped paths
+    // Always add the dbdir and confdir to the skipped paths. This is 
+    // especially important for the rt monitor which will go into a loop if we
+    // don't do this.
     skpl.push_back(getDbDir());
     skpl.push_back(getConfDir());
     for (list<string>::iterator it = skpl.begin(); it != skpl.end(); it++) {
@@ -912,8 +981,10 @@ void RclConfig::initFrom(const RclConfig& r)
     m_maxsufflen = r.m_maxsufflen;
     defcharset = r.defcharset;
     guesscharset = r.guesscharset;
-    m_rmtstr = r.m_rmtstr;
-    m_restrictMTypes = r.m_restrictMTypes;
+
+    m_stpsuffstate.init(this, mimemap, r.m_stpsuffstate.paramname);
+    m_skpnstate.init(this, m_conf, r.m_skpnstate.paramname);
+    m_rmtstate.init(this, m_conf, r.m_rmtstate.paramname);
 }
 
 #else // -> Test
@@ -934,13 +1005,15 @@ using namespace std;
 
 static char *thisprog;
 
-static char usage [] =
-"  \n\n"
+static char usage [] = "\n"
+"-c: check a few things in the configuration files\n"
+"[-s subkey] -q param : query parameter value\n"
+"  : default: print parameters\n"
 ;
 static void
 Usage(void)
 {
-    fprintf(stderr, "%s: usage:\n%s [-s subkey] [-q param]", thisprog, usage);
+    fprintf(stderr, "%s: usage: %s\n", thisprog, usage);
     exit(1);
 }
 
@@ -948,7 +1021,7 @@ static int     op_flags;
 #define OPT_MOINS 0x1
 #define OPT_s	  0x2 
 #define OPT_q	  0x4 
-
+#define OPT_c     0x8
 int main(int argc, char **argv)
 {
     string pname, skey;
@@ -963,6 +1036,7 @@ int main(int argc, char **argv)
 	    Usage();
 	while (**argv)
 	    switch (*(*argv)++) {
+	    case 'c':	op_flags |= OPT_c; break;
 	    case 's':	op_flags |= OPT_s; if (argc < 2)  Usage();
 		skey = *(++argv);
 		argc--; 
@@ -994,8 +1068,42 @@ int main(int argc, char **argv)
 	    exit(1);
 	}
 	printf("[%s] -> [%s]\n", pname.c_str(), value.c_str());
+    } else if (op_flags & OPT_c) {
+        // Check that all known mime types have an icon and belong to
+        // some category
+        list<string> catnames;
+        config->getMimeCategories(catnames);
+        cout << "Categories: ";
+        set<string> allmtsfromcats;
+        for (list<string>::const_iterator it = catnames.begin(); 
+             it != catnames.end(); it++) {
+            cout << *it << " ";
+        }
+        cout << endl;
+        for (list<string>::const_iterator it = catnames.begin(); 
+             it != catnames.end(); it++) {
+            list<string> cts;
+            config->getMimeCatTypes(*it, cts);
+            for (list<string>::const_iterator it1 = cts.begin(); 
+                 it1 != cts.end(); it1++) {
+                // Already in map -> duplicate
+                if (allmtsfromcats.find(*it1) != allmtsfromcats.end()) {
+                    cout << "Duplicate: [" << *it1 << "]" << endl;
+                }
+                allmtsfromcats.insert(*it1);
+            }
+        }
+
+        list<string> mtypes = config->getAllMimeTypes();
+        for (list<string>::const_iterator it = mtypes.begin();
+             it != mtypes.end(); it++) {
+            if (allmtsfromcats.find(*it) == allmtsfromcats.end()) {
+                cout << "Not found in catgs: [" << *it << "]" << endl;
+            }
+        }
     } else {
-	list<string> names = config->getConfNames("");
+        config->setKeyDir("");
+	list<string> names = config->getConfNames();
 	names.sort();
 	names.unique();
 	for (list<string>::iterator it = names.begin(); 
