@@ -29,7 +29,6 @@ static char rcsid[] = "@(#$Id: rclmonrcv.cpp,v 1.15 2008-11-18 13:25:48 dockes E
 #include "rclmon.h"
 #include "rclinit.h"
 #include "fstreewalk.h"
-#include "indexer.h"
 #include "pathut.h"
 
 /**
@@ -60,18 +59,27 @@ static RclMonitor *makeMonitor();
     while we create the watches)*/
 class WalkCB : public FsTreeWalkerCB {
 public:
-    WalkCB(RclConfig *conf, RclMonitor *mon, RclMonEventQueue *queue)
-	: m_conf(conf), m_mon(mon), m_queue(queue)
+    WalkCB(RclConfig *conf, RclMonitor *mon, RclMonEventQueue *queue,
+        FsTreeWalker& walker)
+	: m_config(conf), m_mon(mon), m_queue(queue), m_walker(walker)
     {}
     virtual ~WalkCB() 
     {}
 
     virtual FsTreeWalker::Status 
-    processone(const string &fn, const struct stat *st, FsTreeWalker::CbFlag flg)
+    processone(const string &fn, const struct stat *st, 
+               FsTreeWalker::CbFlag flg)
     {
 	LOGDEB2(("rclMonRcvRun: processone %s m_mon %p m_mon->ok %d\n", 
 		 fn.c_str(), m_mon, m_mon?m_mon->ok():0));
 
+        if (flg == FsTreeWalker::FtwDirEnter || 
+            flg == FsTreeWalker::FtwDirReturn) {
+            m_config->setKeyDir(fn);
+            // Set up skipped patterns for this subtree. 
+            m_walker.setSkippedNames(m_config->getSkippedNames());
+        }
+
 	if (flg == FsTreeWalker::FtwDirEnter) {
 	    // Create watch when entering directory, but first empty
 	    // whatever events we may already have on queue
@@ -100,9 +108,10 @@ public:
     }
 
 private:
-    RclConfig         *m_conf;
+    RclConfig         *m_config;
     RclMonitor        *m_mon;
     RclMonEventQueue  *m_queue;
+    FsTreeWalker&      m_walker;
 };
 
 /** Main thread routine: create watches, then forever wait for and queue events */
@@ -113,6 +122,7 @@ void *rclMonRcvRun(void *q)
     LOGDEB(("rclMonRcvRun: running\n"));
     recoll_threadinit();
 
+
     // Create the fam/whatever interface object
     RclMonitor *mon;
     if ((mon = makeMonitor()) == 0) {
@@ -133,7 +143,7 @@ void *rclMonRcvRun(void *q)
     // Walk the directory trees to add watches
     FsTreeWalker walker;
     walker.setSkippedPaths(queue->getConfig()->getDaemSkippedPaths());
-    WalkCB walkcb(queue->getConfig(), mon, queue);
+    WalkCB walkcb(queue->getConfig(), mon, queue, walker);
     for (list<string>::iterator it = tdl.begin(); it != tdl.end(); it++) {
 	queue->getConfig()->setKeyDir(*it);
 	// Adjust the follow symlinks options
@@ -144,19 +154,19 @@ void *rclMonRcvRun(void *q)
 	} else {
 	    walker.setOpts(FsTreeWalker::FtwOptNone);
 	}
-	// Adjust the skipped names according to config
-	walker.setSkippedNames(queue->getConfig()->getSkippedNames());
-	// Add the dbdir to skipped paths. Note that adding the dbdir
-	// is probably not useful as we'll probably never have
-	// multiple dbs per config file, and the global dbdir is
-	// included by
-	// config->getSkippedPaths(). Still, better to be safe here as
-	// config->including dbdir in the walk will get us into a loop
-	walker.addSkippedPath(queue->getConfig()->getDbDir());
 	LOGDEB(("rclMonRcvRun: walking %s\n", it->c_str()));
 	walker.walk(*it, walkcb);
     }
 
+    bool dobeagle = false;
+    queue->getConfig()->getConfParam("processbeaglequeue", &dobeagle);
+    if (dobeagle) {
+        string beaglequeuedir;
+        if (!queue->getConfig()->getConfParam("beaglequeuedir", beaglequeuedir))
+            beaglequeuedir = path_tildexpand("~/.beagle/ToIndex/");
+        mon->addWatch(beaglequeuedir, true);
+    }
+
     // Forever wait for monitoring events and add them to queue:
     MONDEB(("rclMonRcvRun: waiting for events. q->ok() %d\n", queue->ok()));
     while (queue->ok() && mon->ok()) {
@@ -185,6 +195,9 @@ void *rclMonRcvRun(void *q)
     return 0;
 }
 
+// We dont compile both the inotify and the fam interface and inotify
+// has preference
+#ifndef RCL_USE_INOTIFY
 #ifdef RCL_USE_FAM
 //////////////////////////////////////////////////////////////////////////
 /** Fam/gamin -based monitor class */
@@ -366,7 +379,7 @@ bool RclFAM::getEvent(RclMonEvent& ev, int secs)
     return true;
 }
 #endif // RCL_USE_FAM
-
+#endif // ! INOTIFY
 
 #ifdef RCL_USE_INOTIFY
 //////////////////////////////////////////////////////////////////////////
@@ -558,12 +571,16 @@ bool RclIntf::getEvent(RclMonEvent& ev, int secs)
 // The monitor 'factory'
 static RclMonitor *makeMonitor()
 {
-#ifdef RCL_USE_FAM    
-    return new RclFAM;
-#endif
 #ifdef RCL_USE_INOTIFY
     return new RclIntf;
 #endif
+#ifndef RCL_USE_INOTIFY
+#ifdef RCL_USE_FAM    
+    return new RclFAM;
+#endif
+#endif
+    LOGINFO(("RclMonitor: neither Inotify nor Fam was compiled as "
+             "file system change notification interface\n"));
     return 0;
 }
 #endif // RCL_MONITOR
