@@ -44,6 +44,13 @@ using namespace std;
 #include "wipedir.h"
 #include "rclconfig.h"
 #include "mh_html.h"
+#include "fileudi.h"
+#include "beaglequeue.h"
+#include "cancelcheck.h"
+
+#ifdef RCL_USE_XATTR
+#include "pxattr.h"
+#endif // RCL_USE_XATTR
 
 // The internal path element separator. This can't be the same as the rcldb 
 // file to ipath separator : "|"
@@ -53,10 +60,36 @@ static const string stxtplain("text/plain");
 set<string> FileInterner::o_missingExternal;
 map<string, set<string> >  FileInterner::o_typesForMissing;
 
+#ifdef RCL_USE_XATTR
+void FileInterner::reapXAttrs(const string& path)
+{
+    vector<string> xnames;
+    if (!pxattr::list(path, &xnames)) {
+	LOGERR(("FileInterner::reapXattrs: pxattr::list: errno %d\n", errno));
+	return;
+    }
+    const map<string, string>& xtof = m_cfg->getXattrToField();
+    for (vector<string>::const_iterator it = xnames.begin();
+	 it != xnames.end(); it++) {
+	map<string, string>::const_iterator mit;
+	if ((mit = xtof.find(*it)) != xtof.end()) {
+	    string value;
+	    if (!pxattr::get(path, *it, &value, pxattr::PXATTR_NOFOLLOW)) {
+		LOGERR(("FileInterner::reapXattrs: pxattr::get failed"
+			"for %s, errno %d\n", (*it).c_str(), errno));
+		continue;
+	    }
+	    // Encode should we ?
+	    m_XAttrsFields[mit->second] = value;
+	}
+    }
+}
+#endif // RCL_USE_XATTR
+
 // This is used when the user wants to retrieve a search result doc's parent
 // (ie message having a given attachment)
 bool FileInterner::getEnclosing(const string &url, const string &ipath,
-				string &eurl, string &eipath)
+				string &eurl, string &eipath, string& udi)
 {
     eurl = url;
     eipath = ipath;
@@ -69,6 +102,8 @@ bool FileInterner::getEnclosing(const string &url, const string &ipath,
     } else {
 	eipath.erase();
     }
+    make_udi(url_gpath(eurl), eipath, udi);
+
     LOGDEB(("FileInterner::getEnclosing() after: [%s]\n", eipath.c_str()));
     return true;
 }
@@ -133,25 +168,53 @@ void FileInterner::tmpcleanup()
 //
 // Empty handler on return says that we're in error, this will be
 // processed by the first call to internfile().
+// Split into "constructor calls init()" to allow use from other constructor
 FileInterner::FileInterner(const string &f, const struct stat *stp,
 			   RclConfig *cnf, 
-			   const string& td, const string *imime)
-    : m_cfg(cnf), m_fn(f), m_forPreview(imime?true:false), m_tdir(td)
+			   const string& td, int flags, const string *imime)
+    : m_tdir(td)
 {
+    initcommon(cnf, flags);
+    init(f, stp, cnf, td, flags, imime);
+}
+
+void FileInterner::init(const string &f, const struct stat *stp, RclConfig *cnf,
+                        const string& td, int flags, const string *imime)
+{
+    m_fn = f;
+
+    // This is used by filters which manage some kind of cache.
+    // Indexing by udi makes things easier (because they sometimes get a temp 
+    // as input
+    string udi;
+    make_udi(f, "", udi);
+
+    cnf->setKeyDir(path_getfather(m_fn));
+
+    string l_mime;
     bool usfci = false;
     cnf->getConfParam("usesystemfilecommand", &usfci);
-    LOGDEB(("FileInterner::FileInterner: [%s] mime [%s] preview %d\n", 
-	    f.c_str(), imime?imime->c_str() : "(null)", m_forPreview));
 
-    // We need to run mime type identification in any case to check
-    // for a compressed file.
-    string l_mime = mimetype(m_fn, stp, m_cfg, usfci);
+    if (flags & FIF_doUseInputMimetype) {
+        if (!imime) {
+            LOGERR(("FileInterner::FileInterner: told to use null imime\n"));
+            return;
+        }
+        l_mime = *imime;
+    } else {
+        LOGDEB(("FileInterner::FileInterner: [%s] mime [%s] preview %d\n", 
+                f.c_str(), imime?imime->c_str() : "(null)", m_forPreview));
 
-    // If identification fails, try to use the input parameter. This
-    // is then normally not a compressed type (it's the mime type from
-    // the db), and is only set when previewing, not for indexing
-    if (l_mime.empty() && imime)
-	l_mime = *imime;
+        // We need to run mime type identification in any case to check
+        // for a compressed file.
+        l_mime = mimetype(m_fn, stp, m_cfg, usfci);
+
+        // If identification fails, try to use the input parameter. This
+        // is then normally not a compressed type (it's the mime type from
+        // the db), and is only set when previewing, not for indexing
+        if (l_mime.empty() && imime)
+            l_mime = *imime;
+    }
 
     if (!l_mime.empty()) {
 	// Has mime: check for a compressed file. If so, create a
@@ -193,7 +256,8 @@ FileInterner::FileInterner(const string &f, const struct stat *stp,
     if (!df) {
 	// No handler for this type, for now :( if indexallfilenames
 	// is set in the config, this normally wont happen (we get mh_unknown)
-	LOGERR(("FileInterner:: ignored: [%s] mime [%s]\n", f.c_str(), l_mime.c_str()));
+	LOGINFO(("FileInterner:: ignored: [%s] mime [%s]\n", 
+                 f.c_str(), l_mime.c_str()));
 	return;
     }
     df->set_property(Dijon::Filter::OPERATING_MODE, 
@@ -201,19 +265,164 @@ FileInterner::FileInterner(const string &f, const struct stat *stp,
 
     string charset = m_cfg->getDefCharset();
     df->set_property(Dijon::Filter::DEFAULT_CHARSET, charset);
+    df->set_property(Dijon::Filter::DJF_UDI, udi);
+
+#ifdef RCL_USE_XATTR
+    // Get fields computed from extended attributes. We use the
+    // original file, not the m_fn which may be the uncompressed temp
+    // file
+    reapXAttrs(f);
+#endif //RCL_USE_XATTR
+
     if (!df->set_document_file(m_fn)) {
 	LOGERR(("FileInterner:: error parsing %s\n", m_fn.c_str()));
 	return;
     }
-    m_handlers.reserve(MAXHANDLERS);
-    for (unsigned int i = 0; i < MAXHANDLERS; i++)
-	m_tmpflgs[i] = false;
+
     m_handlers.push_back(df);
     LOGDEB(("FileInterner::FileInterner: %s [%s]\n", l_mime.c_str(), 
 	     m_fn.c_str()));
+}
+
+// Setup from memory data (ie: out of the web cache). imime needs to be set.
+FileInterner::FileInterner(const string &data, RclConfig *cnf, 
+                           const string& td, int flags, const string& imime)
+    : m_tdir(td)
+{
+    initcommon(cnf, flags);
+    init(data, cnf, td, flags, imime);
+}
+
+void FileInterner::init(const string &data, RclConfig *cnf, 
+                        const string& td, int flags, const string& imime)
+{
+    if (imime.empty()) {
+	LOGERR(("FileInterner: inmemory constructor needs input mime type\n"));
+        return;
+    }
+    m_mimetype = imime;
+
+    // Look for appropriate handler (might still return empty)
+    Dijon::Filter *df = getMimeHandler(m_mimetype, m_cfg, !m_forPreview);
+
+    if (!df) {
+	// No handler for this type, for now :( if indexallfilenames
+	// is set in the config, this normally wont happen (we get mh_unknown)
+	LOGINFO(("FileInterner:: ignored: mime [%s]\n", m_mimetype.c_str()));
+	return;
+    }
+    df->set_property(Dijon::Filter::OPERATING_MODE, 
+			    m_forPreview ? "view" : "index");
+
+    string charset = m_cfg->getDefCharset();
+    df->set_property(Dijon::Filter::DEFAULT_CHARSET, charset);
+
+    bool setres = false;
+    if (df->is_data_input_ok(Dijon::Filter::DOCUMENT_STRING)) {
+	setres = df->set_document_string(data);
+    } else if (df->is_data_input_ok(Dijon::Filter::DOCUMENT_DATA)) {
+	setres = df->set_document_data(data.c_str(), data.length());
+    } else if (df->is_data_input_ok(Dijon::Filter::DOCUMENT_FILE_NAME)) {
+	string filename;
+	if (dataToTempFile(data, m_mimetype, filename)) {
+	    if (!(setres=df->set_document_file(filename))) {
+		m_tmpflgs[0] = false;
+		m_tempfiles.pop_back();
+	    }
+	}
+    }
+    if (!setres) {
+	LOGINFO(("FileInterner:: set_doc failed inside for mtype %s\n", 
+                 m_mimetype.c_str()));
+	delete df;
+	return;
+    }
+    m_handlers.push_back(df);
+}
+
+void FileInterner::initcommon(RclConfig *cnf, int flags)
+{
+    m_cfg = cnf;
+    m_forPreview = ((flags & FIF_forPreview) != 0);
+    // Initialize handler stack.
+    m_handlers.reserve(MAXHANDLERS);
+    for (unsigned int i = 0; i < MAXHANDLERS; i++)
+	m_tmpflgs[i] = false;
     m_targetMType = stxtplain;
 }
 
+FileInterner::FileInterner(const Rcl::Doc& idoc, RclConfig *cnf, 
+                           const string& td, int flags)
+    : m_tdir(td)
+{
+    LOGDEB(("FileInterner::FileInterner(idoc)\n"));
+    initcommon(cnf, flags);
+
+    // We do insist on having an url...
+    if (idoc.url.empty()) {
+        LOGERR(("FileInterner::FileInterner:: no url!\n"));
+        return;
+    }
+
+    // This stuff will be moved to some kind of generic function:
+    //   get(idoc, ofn, odata, ometa) 
+    // and use some kind of backstore object factory next time we add a 
+    // backend (if ever). 
+    string backend;
+    map<string, string>::const_iterator it;
+    if ((it = idoc.meta.find(Rcl::Doc::keybcknd)) != idoc.meta.end())
+        backend = it->second;
+    
+    if (backend.empty() || !backend.compare("FS")) {
+        // Filesystem document. Intern from file.
+        // The url has to be like file://
+        if (idoc.url.find("file://") != 0) {
+            LOGERR(("FileInterner: FS backend and non fs url: [%s]\n",
+                    idoc.url.c_str()));
+            return;
+        }
+        string fn = idoc.url.substr(7, string::npos);
+        struct stat st;
+        if (stat(fn.c_str(), &st) < 0) {
+            LOGERR(("FileInterner:: cannot access document file: [%s]\n",
+                    fn.c_str()));
+            return;
+        }
+        init(fn, &st, cnf, td, flags, &idoc.mimetype);
+    } else if (!backend.compare("BGL")) {
+        // Retrieve from our webcache (beagle data). There should
+        // probably be a separate object type for readonly cache
+        // access (distinct from the one used for indexing). 
+        // Anyway, we're not called in the same thread as indexing ops, and
+        // even, at worse, this would duplicate the memory used. The beagler
+        // object is created at the first call of this routine and deleted 
+        // when the program exits.
+        static BeagleQueueIndexer beagler(cnf);
+        string data;
+        Rcl::Doc dotdoc;
+        map<string,string>::const_iterator it = 
+            idoc.meta.find(Rcl::Doc::keyudi);
+        if (it == idoc.meta.end() || it->second.empty()) {
+            LOGERR(("FileInterner:: no udi in idoc\n"));
+            return;
+        }
+        string udi = it->second;
+        if (!beagler.getFromCache(udi, dotdoc, data)) {
+            LOGINFO(("FileInterner:: failed fetch from Beagle cache for [%s]\n",
+                     udi.c_str()));
+            return;
+        }
+        if (dotdoc.mimetype.compare(idoc.mimetype)) {
+            LOGINFO(("FileInterner:: udi [%s], mimetp mismatch: in: [%s], bgl "
+                     "[%s]\n", idoc.mimetype.c_str(), dotdoc.mimetype.c_str()));
+        }
+        init(data, cnf, td, flags, dotdoc.mimetype);
+    } else {
+        LOGERR(("FileInterner:: unknown backend: [%s]\n", backend.c_str()));
+        return;
+    }
+}
+
 FileInterner::~FileInterner()
 {
     tmpcleanup();
@@ -233,7 +442,10 @@ bool FileInterner::dataToTempFile(const string& dt, const string& mt,
     // Find appropriate suffix for mime type
     TempFile temp(new TempFileInternal(m_cfg->getSuffixFromMimeType(mt)));
     if (temp->ok()) {
-	m_tmpflgs[m_handlers.size()-1] = true;
+        // We are called before the handler is actually on the stack, so the
+        // index is m_handlers.size(). m_tmpflgs is a static array, so this is
+        // no problem
+	m_tmpflgs[m_handlers.size()] = true;
 	m_tempfiles.push_back(temp);
     } else {
 	LOGERR(("FileInterner::dataToTempFile: cant create tempfile: %s\n",
@@ -363,18 +575,6 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
 	doc.meta[Rcl::Doc::keyabs] = doc.meta[keyds];
 	doc.meta.erase(keyds);
     }
-#ifdef RCL_USE_XATTR
-    // Finally set any data possibly coming out of the extended file attributes
-    // these override any values from inside the file.
-    RecollFilter *rf = dynamic_cast<RecollFilter*>(df);
-    if (rf != 0) {
-	const map<string, string>& ffa = rf->getFieldsFromAttrs();
-	for (map<string,string>::const_iterator it = ffa.begin(); 
-	     it != ffa.end(); it++) {
-	    doc.meta[it->first] = it->second;
-	}
-    }
-#endif //RCL_USE_XATTR
     return true;
 }
 
@@ -388,6 +588,15 @@ void FileInterner::collectIpathAndMT(Rcl::Doc& doc, string& ipath) const
 {
     bool hasipath = false;
 
+#ifdef RCL_USE_XATTR
+    // Set fields from extended file attributes.
+    // These can be overriden by values from inside the file
+    for (map<string,string>::const_iterator it = m_XAttrsFields.begin(); 
+	 it != m_XAttrsFields.end(); it++) {
+	doc.meta[it->first] = it->second;
+    }
+#endif //RCL_USE_XATTR
+
     // If there is no ipath stack, the mimetype is the one from the file
     doc.mimetype = m_mimetype;
 
@@ -500,7 +709,7 @@ int FileInterner::addHandler()
 	string filename;
 	if (dataToTempFile(*txt, mimetype, filename)) {
 	    if (!(setres = newflt->set_document_file(filename))) {
-		m_tmpflgs[m_handlers.size()-1] = false;
+		m_tmpflgs[m_handlers.size()] = false;
 		m_tempfiles.pop_back();
 	    }
 	}
@@ -565,6 +774,7 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
     // security in the form of a maximum handler stack size.
     int loop = 0;
     while (!m_handlers.empty()) {
+        CancelCheck::instance().checkCancel();
 	if (loop++ > 1000) {
 	    LOGERR(("FileInterner:: looping!\n"));
 	    return FIError;
@@ -572,6 +782,15 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	// If there are no more docs at the current top level we pop and
 	// see if there is something at the previous one
 	if (!m_handlers.back()->has_documents()) {
+            // If looking for a specific doc, this is an error. Happens if
+            // the index is stale, and the ipath points to the wrong message
+            // for exemple (one with less attachments)
+	    if (m_forPreview) {
+                m_reason += "Requested document does not exist. ";
+                m_reason += m_handlers.back()->get_error();
+                LOGERR(("FileInterner: requested document does not exist\n"));
+		return FIError;
+            }
 	    popHandler();
 	    continue;
 	}
@@ -581,8 +800,12 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	// still want to process the rest of the mbox! For preview: fatal.
 	if (!m_handlers.back()->next_document()) {
 	    processNextDocError(doc, ipath);
-	    if (m_forPreview) 
+	    if (m_forPreview) {
+                m_reason += "Requested document does not exist. ";
+                m_reason += m_handlers.back()->get_error();
+                LOGERR(("FileInterner: requested document does not exist\n"));
 		return FIError;
+            }
 	    popHandler();
 	    continue;
 	}
@@ -610,18 +833,17 @@ FileInterner::Status FileInterner::internfile(Rcl::Doc& doc, string& ipath)
 	}
     }
  breakloop:
-
     if (m_handlers.empty()) {
 	LOGDEB(("FileInterner::internfile: conversion ended with no doc\n"));
 	return FIError;
     }
 
-    // If indexing compute ipath and significant mimetype.
-    // ipath is returned through the parameter not doc.ipath We also
-    // retrieve some metadata fields from the ancesters (like date or
+    // If indexing compute ipath and significant mimetype.  ipath is
+    // returned through the parameter not doc.ipath We also retrieve
+    // some metadata fields from the ancesters (like date or
     // author). This is useful for email attachments. The values will
-    // be replaced by those found by dijontorcl if any, so the order
-    // of calls is important.
+    // be replaced by those internal to the document (by dijontorcl())
+    // if any, so the order of calls is important.
     if (!m_forPreview)
 	collectIpathAndMT(doc, ipath);
     else
@@ -662,9 +884,16 @@ class DirWiper {
     }
 };
 
+// Temporary while we fix backend things
+static string urltolocalpath(string url)
+{
+    return url.substr(7, string::npos);
+}
+
 // Extract subdoc out of multidoc into temporary file. 
 // We do the usual internfile stuff: create a temporary directory,
-// then create an interner and call internfile. 
+// then create an interner and call internfile. The target mtype is set to
+// the input mtype, so that no data conversion is performed.
 // We then write the data out of the resulting document into the output file.
 // There are two temporary objects:
 // - The internfile temporary directory gets destroyed before we
@@ -672,11 +901,13 @@ class DirWiper {
 // - The output temporary file which is held in a reference-counted
 //   object and will be deleted when done with.
 bool FileInterner::idocToFile(TempFile& otemp, const string& tofile,
-			      RclConfig *cnf, 
-			      const string& fn,
-			      const string& ipath,
-			      const string& mtype)
+			      RclConfig *cnf, const Rcl::Doc& idoc)
 {
+    LOGDEB(("FileInterner::idocToFile\n"));
+    idoc.dump();
+    string fn = urltolocalpath(idoc.url);
+    string ipath = idoc.ipath;
+    string mtype = idoc.mimetype;
     struct stat st;
     if (stat(fn.c_str(), &st) < 0) {
 	LOGERR(("FileInterner::idocToFile: can't stat [%s]\n", fn.c_str()));
@@ -688,7 +919,10 @@ bool FileInterner::idocToFile(TempFile& otemp, const string& tofile,
 	return false;
     DirWiper wiper(tmpdir);
 
-    FileInterner interner(fn, &st, cnf, tmpdir, &mtype);
+    // We set FIF_forPreview for consistency with the previous version
+    // which determined this by looking at mtype!=null. Probably
+    // doesn't change anything in this case.
+    FileInterner interner(fn, &st, cnf, tmpdir, FIF_forPreview, &mtype);
     interner.setTargetMType(mtype);
     Rcl::Doc doc;
     string mipath = ipath;
@@ -811,7 +1045,7 @@ int main(int argc, char **argv)
 	perror("stat");
 	exit(1);
     }
-    FileInterner interner(fn, &st, config, "/tmp");
+    FileInterner interner(fn, &st, config, "/tmp", 0);
     Rcl::Doc doc;
     FileInterner::Status status = interner.internfile(doc, ipath);
     switch (status) {
