@@ -52,6 +52,8 @@ static const string cstr_author = "author";
 static const string cstr_recipient = "recipient";
 static const string cstr_modificationdate = "modificationdate";
 static const string cstr_title = "title";
+static const string cstr_msgid = "msgid";
+static const string cstr_abstract = "abstract";
 
 MimeHandlerMail::~MimeHandlerMail() 
 {
@@ -165,11 +167,19 @@ bool MimeHandlerMail::next_document()
 	res = processMsg(m_bincdoc, 0);
 	LOGDEB1(("MimeHandlerMail::next_document: mimetype %s\n",
 		m_metaData[cstr_mimetype].c_str()));
+        const string& txt = m_metaData[cstr_content];
+        if (m_startoftext < txt.size())
+            m_metaData[cstr_abstract] = 
+                truncate_to_word(txt.substr(m_startoftext), 250);
     } else {
+        m_metaData[cstr_abstract] = "";
 	res = processAttach();
     }
     m_idx++;
     m_havedoc = m_idx < (int)m_attachments.size();
+    if (!m_havedoc) {
+        m_reason = "Subdocument index too high";
+    }
     return res;
 }
 
@@ -313,6 +323,12 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	    m_metaData[cstr_recipient] += " " + transcoded;
 	}
     }
+    if (doc->h.getFirstHeader("Message-Id", hi)) {
+	if (depth == 1) {
+	    m_metaData[cstr_msgid] =  hi.getValue();
+            trimstring(m_metaData[cstr_msgid], "<>");
+	}
+    }
     if (doc->h.getFirstHeader("Date", hi)) {
 	rfc2047_decode(hi.getValue(), transcoded);
 	if (depth == 1) {
@@ -337,7 +353,7 @@ bool MimeHandlerMail::processMsg(Binc::MimePart *doc, int depth)
 	text += string("Subject: ") + transcoded + string("\n");
     }
     text += '\n';
-
+    m_startoftext = text.size();
     LOGDEB2(("MimeHandlerMail::processMsg:ismultipart %d mime subtype '%s'\n",
 	    doc->isMultipart(), doc->getSubType().c_str()));
     walkmime(doc, depth);
@@ -476,7 +492,7 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
     // mailer used by yahoo support ('KANA') does this. We could convert 
     // to iso-8859 only if the transfer-encoding is 8 bit, or test for
     // actual 8 bit chars, but what the heck, le'ts use 8859-1 as default
-    string charset = "iso-8859-1";
+    string charset;
     it = content_type.params.find(string("charset"));
     if (it != content_type.params.end())
 	charset = it->second;
@@ -486,7 +502,9 @@ void MimeHandlerMail::walkmime(Binc::MimePart* doc, int depth)
 	!stringlowercmp("x-user-defined", charset) || 
 	!stringlowercmp("x-unknown", charset) || 
 	!stringlowercmp("unknown", charset) ) {
-	charset = "iso-8859-1";
+        RclConfig::getMainConfig()->getConfParam("maildefcharset", charset);
+        if (charset.empty())
+            charset = "iso-8859-1";
     }
 
     // Content transfer encoding
