@@ -16,7 +16,7 @@
  */
 #ifndef _MH_UNKNOWN_H_INCLUDED_
 #define _MH_UNKNOWN_H_INCLUDED_
-/* @(#$Id: mh_unknown.h,v 1.3 2008/10/04 14:26:59 dockes Exp $  (C) 2004 J.F.Dockes */
+/* @(#$Id: mh_unknown.h,v 1.3 2008-10-04 14:26:59 dockes Exp $  (C) 2004 J.F.Dockes */
 
 #include <string>
 
@@ -30,7 +30,8 @@ class MimeHandlerUnknown : public RecollFilter {
  public:
     MimeHandlerUnknown(const string& mt) : RecollFilter(mt) {}
     virtual ~MimeHandlerUnknown() {}
-    virtual bool set_document_string(const string&) {
+    virtual bool set_document_string(const string& fn) {
+	RecollFilter::set_document_file(fn);
 	return m_havedoc = true;
     }
     virtual bool set_document_file(const string&) {
