@@ -4,7 +4,7 @@
     <name>AdvSearch</name>
     <message>
         <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation type="unfinished">Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
+        <translation>Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
     </message>
     <message>
         <source>All clauses</source>
@@ -175,7 +175,7 @@
     </message>
     <message>
         <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
-        <translation type="unfinished"></translation>
+        <translation>Все непустые поля справа будут объединены логическим И (&quot;все слова&quot;) или ИЛИ (&quot;любое слово&quot;). &lt;br&gt;Поля типа &quot;любые&quot;, &quot;все&quot; или &quot;без этих&quot; принимают набор простых слов и фразы, заключённые в двойные кавычки.&lt;br&gt;Пустые поля игнорируются.</translation>
     </message>
 </context>
 <context>
@@ -275,7 +275,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>File does not exist</source>
-        <translation>Файл не существует</translation>
+        <translation type="obsolete">Файл не существует</translation>
     </message>
     <message>
         <source>Missing helper program: </source>
@@ -333,10 +333,18 @@ Click Cancel if you want to edit the configuration file before indexation starts
     <name>PreviewTextEdit</name>
     <message>
         <source>Show fields</source>
-        <translation type="unfinished"></translation>
+        <translation>Показать поля</translation>
     </message>
     <message>
         <source>Show main text</source>
+        <translation>Показать основной текст</translation>
+    </message>
+    <message>
+        <source>Print</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print Current Preview</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -394,6 +402,10 @@ Click Cancel if you want to edit the configuration file before indexation starts
         <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
         <translation>Индексировать и те имена файлов, для которых не получается определить или обработать содержимое (неизвестный или неподдерживаемый тип MIME).  Обычно так</translation>
     </message>
+    <message>
+        <source>Beagle web history</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGuiResListPager</name>
@@ -454,7 +466,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>Cannot access document file: </source>
-        <translation>Невозможно открыть документ: </translation>
+        <translation type="obsolete">Невозможно открыть документ: </translation>
     </message>
     <message>
         <source>Preview</source>
@@ -470,7 +482,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>No external viewer configured for mime type </source>
-        <translation>Неизвестна программа просмотра для </translation>
+        <translation type="obsolete">Неизвестна программа просмотра для </translation>
     </message>
     <message>
         <source>Executing: [</source>
@@ -541,7 +553,7 @@ Please check the mimeconf file</source>
     <message>
         <source>The viewer specified in mimeconf for %1: %2 is not found.
 Do you want to start the  preferences dialog ?</source>
-        <translation>Программа просмотра, указанная в mimeconf для %1: %2, не найдена.
+        <translation type="obsolete">Программа просмотра, указанная в mimeconf для %1: %2, не найдена.
 Открыть диалог настроек?</translation>
     </message>
     <message>
@@ -562,76 +574,91 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Update &amp;Index</source>
-        <translation type="unfinished"></translation>
+        <translation>Обновить &amp;индекс</translation>
     </message>
     <message>
         <source>Indexing interrupted</source>
-        <translation type="unfinished"></translation>
+        <translation>Индексирование прервано</translation>
     </message>
     <message>
         <source>Stop &amp;Indexing</source>
-        <translation type="unfinished"></translation>
+        <translation>П&amp;рервать индексирование</translation>
     </message>
     <message>
         <source>Can&apos;t start query: </source>
-        <translation type="unfinished"></translation>
+        <translation>Ошибка старта запроса:</translation>
     </message>
     <message>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>все</translation>
     </message>
     <message>
         <source>media</source>
-        <translation type="unfinished">мультимедиа</translation>
+        <translation>медиа</translation>
     </message>
     <message>
         <source>message</source>
-        <translation type="unfinished"></translation>
+        <translation>сообщения</translation>
     </message>
     <message>
         <source>other</source>
-        <translation type="unfinished">иное</translation>
+        <translation>иное</translation>
     </message>
     <message>
         <source>presentation</source>
-        <translation type="unfinished"></translation>
+        <translation>презентации</translation>
     </message>
     <message>
         <source>spreadsheet</source>
-        <translation type="unfinished"></translation>
+        <translation>таблицы</translation>
     </message>
     <message>
         <source>text</source>
-        <translation type="unfinished"></translation>
+        <translation>текст</translation>
     </message>
     <message>
         <source>sorted</source>
-        <translation type="unfinished"></translation>
+        <translation>сортированное</translation>
     </message>
     <message>
         <source>filtered</source>
-        <translation type="unfinished"></translation>
+        <translation>фильтрованное</translation>
     </message>
     <message>
         <source>External applications/commands needed and not found for indexing your file types:
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Отсутствующие внешние приложения/команды, требуемые для индексирования ваших файлов:
+
+</translation>
     </message>
     <message>
         <source>No helpers found missing</source>
-        <translation type="unfinished"></translation>
+        <translation>Все вспомогательные программы доступны</translation>
     </message>
     <message>
         <source>Missing helper programs</source>
-        <translation type="unfinished"></translation>
+        <translation>Недостающие вспомогательные программы</translation>
     </message>
     <message>
         <source>Save file dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить файл</translation>
     </message>
     <message>
         <source>Choose a file name to save under</source>
+        <translation>Выберите имя файла для сохранения</translation>
+    </message>
+    <message>
+        <source>Document category filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No external viewer configured for mime type [</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The viewer specified in mimeview for %1: %2 is not found.
+Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -787,11 +814,11 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>все</translation>
     </message>
     <message>
         <source>&amp;Show missing helpers</source>
-        <translation type="unfinished"></translation>
+        <translation>Недостающие внешние программы</translation>
     </message>
 </context>
 <context>
@@ -984,7 +1011,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Unavailable document</source>
-        <translation type="unfinished">Документ недоступен</translation>
+        <translation>Документ недоступен</translation>
     </message>
     <message>
         <source>Show query details</source>
@@ -998,15 +1025,15 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Previous</source>
-        <translation type="unfinished">Предыдущая</translation>
+        <translation>Предыдущая</translation>
     </message>
     <message>
         <source>Next</source>
-        <translation type="unfinished">Следующая</translation>
+        <translation>Следующая</translation>
     </message>
     <message>
         <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
-        <translation type="unfinished">&lt;p&gt;&lt;b&gt;Не найдено&lt;/b&gt;&lt;br&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;Не найдено&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
@@ -1042,7 +1069,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>P&amp;arent document/folder</source>
-        <translation>&amp;Родительский документ/каталог</translation>
+        <translation type="obsolete">&amp;Родительский документ/каталог</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
@@ -1054,38 +1081,54 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Copy &amp;URL</source>
-        <translation type="unfinished"></translation>
+        <translation>Копировать &amp;URL</translation>
     </message>
     <message>
         <source>filtered</source>
-        <translation type="unfinished"></translation>
+        <translation>фильтрованное</translation>
     </message>
     <message>
         <source>sorted</source>
-        <translation type="unfinished"></translation>
+        <translation>сортированное</translation>
     </message>
     <message>
         <source>Document history</source>
-        <translation type="unfinished">История документов</translation>
+        <translation>История документов</translation>
     </message>
     <message>
         <source>Save to File</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Сохранить в файл</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
+        <translation>Документы &lt;b&gt;%d-%d&lt;/b&gt; из минимум &lt;b&gt;%d&lt;/b&gt; для</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
+        <translation>Документы &lt;b&gt;%d-%d&lt;/b&gt; для</translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished">Предв. просмотр</translation>
+        <translation>Предпросмотр</translation>
     </message>
     <message>
         <source>Open</source>
+        <translation>Открыть</translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1225,7 +1268,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Choose search type.</source>
-        <translation type="unfinished"></translation>
+        <translation>Выберите тип поиска</translation>
     </message>
 </context>
 <context>
@@ -1812,26 +1855,30 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Highlight color for query terms</source>
-        <translation type="unfinished"></translation>
+        <translation>Цвет выделения ключевых слов</translation>
     </message>
     <message>
         <source>Deactivate All</source>
-        <translation type="unfinished"></translation>
+        <translation>Выключить все</translation>
     </message>
     <message>
         <source>Prefer Html to plain text for preview.</source>
-        <translation type="unfinished"></translation>
+        <translation>Предпочитать HTML тексту для предпросмотра</translation>
     </message>
     <message>
         <source>If checked, results with the same content under different names will only be shown once.</source>
-        <translation type="unfinished"></translation>
+        <translation>Показывать результаты с тем же содержанием под разными именами не более одного раза</translation>
     </message>
     <message>
         <source>Hide duplicate results.</source>
-        <translation type="unfinished"></translation>
+        <translation>Прятать дубликаты</translation>
     </message>
     <message>
         <source>Choose editor applications</source>
+        <translation>Выбор редакторов</translation>
+    </message>
+    <message>
+        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1870,6 +1917,10 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Select one or several mime types then click &quot;Change Action&quot;</source>
+        <translation type="obsolete">Выберите один или несколько MIME-типов и нажмите &quot;Сменить действие&quot;</translation>
+    </message>
+    <message>
+        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1960,6 +2011,33 @@ This should give higher precedence to the results where the search terms appear
         <translation type="obsolete">Невозможно выполнить полностью негативный запрос. Пожалуйста, введите общие термины в поле &quot;любые слова&quot;</translation>
     </message>
 </context>
+<context>
+    <name>confgui::ConfBeaglePanelW</name>
+    <message>
+        <source>Steal Beagle indexing queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Web cache directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. size for the web cache (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Entries will be recycled once the size is reached</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>confgui::ConfIndexW</name>
     <message>
@@ -1993,10 +2071,37 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Max. compressed file size (KB)</source>
-        <translation type="unfinished"></translation>
+        <translation>Предел размера сжатого файла (KB)</translation>
     </message>
     <message>
         <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
+        <translation>Это значение устанавливает порог размера сжатых файлов, которые будут обрабатываться. -1 отключает порог, 0 отключает декомпрессию.</translation>
+    </message>
+    <message>
+        <source>Max. text file size (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
+This is for excluding monster log files from the index.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text file page size (KB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
+This will help searching very big text  files (ie: log files).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. filter exec. time (S)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
+</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -2092,15 +2197,15 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
-        <translation type="unfinished"></translation>
+        <translation>Имена каталогов, которые индексирование обойдёт.&lt;br&gt;Может содержать шаблоны.  Обязано подходить к путям, которые видит индексатор (например, если topdirs включает &apos;/home/me&apos; и &apos;/home&apos; является ссылкой на &apos;/usr/home&apos;, то правильная запись должна быть &apos;/home/me/tmp*&apos;, а не &apos;/usr/home/me/tmp*&apos;)</translation>
     </message>
     <message>
         <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
-        <translation type="unfinished"></translation>
+        <translation>Это значение определяет количество проиндексированных данных между сбросами на диск.&lt;br&gt;Помогает контролировать использование памяти при индексации.  Обычно 10Mb </translation>
     </message>
     <message>
         <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
-        <translation type="unfinished"></translation>
+        <translation>Отключает использование aspell для генерации приближений написания в навигаторе терминов.&lt;br&gt; Полезно, если aspell отсутствует или сломан. </translation>
     </message>
 </context>
 </TS>
