@@ -167,7 +167,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>File does not exist</source>
-        <translation>Dosya yok</translation>
+        <translation type="obsolete">Dosya yok</translation>
     </message>
     <message>
         <source>Cancel</source>
@@ -263,6 +263,14 @@ Click Cancel if you want to edit the configuration file before indexation starts
         <source>Show main text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Print</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print Current Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -318,6 +326,10 @@ Click Cancel if you want to edit the configuration file before indexation starts
         <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
         <translation>İçeriği tanınmayan ya da işlenemeyen (ya da desteklenmeyen mime tipi) dosyaları indeksle. Öntanımlı evet</translation>
     </message>
+    <message>
+        <source>Beagle web history</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGuiResListPager</name>
@@ -402,7 +414,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>Cannot access document file: </source>
-        <translation>Belge dosyasına erişilemedi: </translation>
+        <translation type="obsolete">Belge dosyasına erişilemedi: </translation>
     </message>
     <message>
         <source>Warning</source>
@@ -418,7 +430,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>No external viewer configured for mime type </source>
-        <translation>Mime tipi için bir dış gösterici ayarlanmamış</translation>
+        <translation type="obsolete">Mime tipi için bir dış gösterici ayarlanmamış</translation>
     </message>
     <message>
         <source>Bad viewer command line for %1: [%2]
@@ -429,7 +441,7 @@ Lütfen mimeconf dosyasını kontrol edin</translation>
     <message>
         <source>The viewer specified in mimeconf for %1: %2 is not found.
 Do you want to start the  preferences dialog ?</source>
-        <translation>%1 için mimeconf dosyasında belirtilen gösterici: %2 bulunamadı.
+        <translation type="obsolete">%1 için mimeconf dosyasında belirtilen gösterici: %2 bulunamadı.
 Tercihler penceresini  açmak ister misiniz?</translation>
     </message>
     <message>
@@ -526,6 +538,19 @@ Tercihler penceresini  açmak ister misiniz?</translation>
         <source>Choose a file name to save under</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Document category filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No external viewer configured for mime type [</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The viewer specified in mimeview for %1: %2 is not found.
+Do you want to start the  preferences dialog ?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RclMainBase</name>
@@ -718,7 +743,7 @@ Tercihler penceresini  açmak ister misiniz?</translation>
     </message>
     <message>
         <source>P&amp;arent document/folder</source>
-        <translation>Ü&amp;st belge/dizin</translation>
+        <translation type="obsolete">Ü&amp;st belge/dizin</translation>
     </message>
     <message>
         <source>Query details</source>
@@ -736,10 +761,6 @@ Tercihler penceresini  açmak ister misiniz?</translation>
         <source>Document history</source>
         <translation type="unfinished">Belge geçmişi</translation>
     </message>
-    <message>
-        <source>Save to File</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
         <translation type="unfinished"></translation>
@@ -756,6 +777,22 @@ Tercihler penceresini  açmak ister misiniz?</translation>
         <source>Open</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SSearch</name>
@@ -1207,6 +1244,10 @@ Büyük boyutlu belgelerde yavaş olabilir.</translation>
         <source>Choose editor applications</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewAction</name>
@@ -1242,7 +1283,34 @@ Büyük boyutlu belgelerde yavaş olabilir.</translation>
         <translation>Kapat</translation>
     </message>
     <message>
-        <source>Select one or several mime types then click &quot;Change Action&quot;</source>
+        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>confgui::ConfBeaglePanelW</name>
+    <message>
+        <source>Steal Beagle indexing queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Web cache directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. size for the web cache (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Entries will be recycled once the size is reached</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1285,6 +1353,33 @@ Büyük boyutlu belgelerde yavaş olabilir.</translation>
         <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Max. text file size (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
+This is for excluding monster log files from the index.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text file page size (KB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
+This will help searching very big text  files (ie: log files).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. filter exec. time (S)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>confgui::ConfTopPanelW</name>
