@@ -4,7 +4,7 @@
     <name>AdvSearch</name>
     <message>
         <source>Cannot execute pure negative query. Please enter common terms in the &apos;any words&apos; field</source>
-        <translation type="unfinished">Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
+        <translation>Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
     </message>
     <message>
         <source>All clauses</source>
@@ -175,7 +175,7 @@
     </message>
     <message>
         <source>All non empty fields on the right will be combined with AND (&quot;All clauses&quot; choice) or OR (&quot;Any clause&quot; choice) conjunctions. &lt;br&gt;&quot;Any&quot; &quot;All&quot; and &quot;None&quot; field types can accept a mix of simple words, and phrases enclosed in double quotes.&lt;br&gt;Fields with no data are ignored.</source>
-        <translation type="unfinished"></translation>
+        <translation>Всі непусті поля буде об&apos;єднано за допомогою АБО (&quot;усі слова&quot;) або ТА (&quot;будь-які слова&quot;).&lt;br&gt;Поля типу &quot;будь-які слова&quot;, &quot;усі слова&quot; та &quot;без цих слів&quot; приймають суміш слів та фраз у подвійних лапках.&lt;br&gt;Поля без даних не беруться до уваги.</translation>
     </message>
 </context>
 <context>
@@ -272,7 +272,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>File does not exist</source>
-        <translation>Файл не існує</translation>
+        <translation type="obsolete">Файл не існує</translation>
     </message>
     <message>
         <source>Missing helper program: </source>
@@ -330,10 +330,18 @@ Click Cancel if you want to edit the configuration file before indexation starts
     <name>PreviewTextEdit</name>
     <message>
         <source>Show fields</source>
-        <translation type="unfinished"></translation>
+        <translation>Показувати поля</translation>
     </message>
     <message>
         <source>Show main text</source>
+        <translation>Показувати основний текст</translation>
+    </message>
+    <message>
+        <source>Print</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print Current Preview</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -391,6 +399,10 @@ Click Cancel if you want to edit the configuration file before indexation starts
         <source>Index the names of files for which the contents cannot be identified or processed (no or unsupported mime type). Default true</source>
         <translation>Індексувати також назви файлів, вміст яких не може бути впізнано чи оброблено (невідомий або непідтримуваний тип MIME).  Типово &quot;так&quot;</translation>
     </message>
+    <message>
+        <source>Beagle web history</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QtGuiResListPager</name>
@@ -451,7 +463,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>Cannot access document file: </source>
-        <translation>Не можу прочитати файл: </translation>
+        <translation type="obsolete">Не можу прочитати файл: </translation>
     </message>
     <message>
         <source>Preview</source>
@@ -467,7 +479,7 @@ Click Cancel if you want to edit the configuration file before indexation starts
     </message>
     <message>
         <source>No external viewer configured for mime type </source>
-        <translation>Не знаю переглядача для mime-типа </translation>
+        <translation type="obsolete">Не знаю переглядача для mime-типа </translation>
     </message>
     <message>
         <source>Executing: [</source>
@@ -534,7 +546,7 @@ Please check the mimeconf file</source>
     <message>
         <source>The viewer specified in mimeconf for %1: %2 is not found.
 Do you want to start the  preferences dialog ?</source>
-        <translation>Не знайдено вказаний в mimeconf для %1 переглядач %2.
+        <translation type="obsolete">Не знайдено вказаний в mimeconf для %1 переглядач %2.
 Відкрити діалог налаштувань?</translation>
     </message>
     <message>
@@ -555,76 +567,91 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Update &amp;Index</source>
-        <translation type="unfinished"></translation>
+        <translation>Поновити &amp;індекс</translation>
     </message>
     <message>
         <source>Indexing interrupted</source>
-        <translation type="unfinished"></translation>
+        <translation>Індексування перервано</translation>
     </message>
     <message>
         <source>Stop &amp;Indexing</source>
-        <translation type="unfinished"></translation>
+        <translation>Пе&amp;рервати індексування</translation>
     </message>
     <message>
         <source>Can&apos;t start query: </source>
-        <translation type="unfinished"></translation>
+        <translation>Неможливо почати запит:</translation>
     </message>
     <message>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>всі</translation>
     </message>
     <message>
         <source>media</source>
-        <translation type="unfinished">мультимедіа</translation>
+        <translation>медіа</translation>
     </message>
     <message>
         <source>message</source>
-        <translation type="unfinished"></translation>
+        <translation>повідомлення</translation>
     </message>
     <message>
         <source>other</source>
-        <translation type="unfinished">інше</translation>
+        <translation>інше</translation>
     </message>
     <message>
         <source>presentation</source>
-        <translation type="unfinished"></translation>
+        <translation>презентації</translation>
     </message>
     <message>
         <source>spreadsheet</source>
-        <translation type="unfinished"></translation>
+        <translation>таблиці</translation>
     </message>
     <message>
         <source>text</source>
-        <translation type="unfinished"></translation>
+        <translation>текст</translation>
     </message>
     <message>
         <source>sorted</source>
-        <translation type="unfinished"></translation>
+        <translation>сортоване</translation>
     </message>
     <message>
         <source>filtered</source>
-        <translation type="unfinished"></translation>
+        <translation>фільтроване</translation>
     </message>
     <message>
         <source>External applications/commands needed and not found for indexing your file types:
 
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Відсутні зовнішні додатки/команди, що потрібні для індексування ваших документів:
+
+</translation>
     </message>
     <message>
         <source>No helpers found missing</source>
-        <translation type="unfinished"></translation>
+        <translation>Всі додаткові програми наявні</translation>
     </message>
     <message>
         <source>Missing helper programs</source>
-        <translation type="unfinished"></translation>
+        <translation>Відсутні додаткові програми</translation>
     </message>
     <message>
         <source>Save file dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Зберегти файл</translation>
     </message>
     <message>
         <source>Choose a file name to save under</source>
+        <translation>Оберіть ім&apos;я файла для збереження</translation>
+    </message>
+    <message>
+        <source>Document category filter</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No external viewer configured for mime type [</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The viewer specified in mimeview for %1: %2 is not found.
+Do you want to start the  preferences dialog ?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -780,11 +807,11 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>All</source>
-        <translation type="unfinished"></translation>
+        <translation>всі</translation>
     </message>
     <message>
         <source>&amp;Show missing helpers</source>
-        <translation type="unfinished"></translation>
+        <translation>Відсутні програми</translation>
     </message>
 </context>
 <context>
@@ -844,7 +871,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Unavailable document</source>
-        <translation type="unfinished">Документ недосяжний</translation>
+        <translation>Документ недосяжний</translation>
     </message>
     <message>
         <source>Show query details</source>
@@ -858,15 +885,15 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Previous</source>
-        <translation type="unfinished">Попередня</translation>
+        <translation>Попередня</translation>
     </message>
     <message>
         <source>Next</source>
-        <translation type="unfinished">Наступна</translation>
+        <translation>Наступна</translation>
     </message>
     <message>
         <source>&lt;p&gt;&lt;b&gt;No results found&lt;/b&gt;&lt;br&gt;</source>
-        <translation type="unfinished">&lt;p&gt;&lt;b&gt;Не знайдено&lt;/b&gt;&lt;br&gt;</translation>
+        <translation>&lt;p&gt;&lt;b&gt;Не знайдено&lt;/b&gt;&lt;br&gt;</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
@@ -902,7 +929,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>P&amp;arent document/folder</source>
-        <translation>&amp;Батьківський документ/тека</translation>
+        <translation type="obsolete">&amp;Батьківський документ/тека</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%1-%2&lt;/b&gt; out of at least &lt;b&gt;%3&lt;/b&gt; for </source>
@@ -914,38 +941,54 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Copy &amp;URL</source>
-        <translation type="unfinished"></translation>
+        <translation>Копіювати &amp;URL</translation>
     </message>
     <message>
         <source>filtered</source>
-        <translation type="unfinished"></translation>
+        <translation>фільтроване</translation>
     </message>
     <message>
         <source>sorted</source>
-        <translation type="unfinished"></translation>
+        <translation>сортоване</translation>
     </message>
     <message>
         <source>Document history</source>
-        <translation type="unfinished">Історія документів</translation>
+        <translation>Історія документів</translation>
     </message>
     <message>
         <source>Save to File</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Зберегти в файл</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; out of at least &lt;b&gt;%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
+        <translation>Документи &lt;b&gt;%d-%d&lt;/b&gt; з принаймні &lt;b&gt;%d&lt;/b&gt; по</translation>
     </message>
     <message>
         <source>Documents &lt;b&gt;%d-%d&lt;/b&gt; for </source>
-        <translation type="unfinished"></translation>
+        <translation>Документи &lt;b&gt;%d-%d&lt;/b&gt; по </translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished">Перегляд</translation>
+        <translation>Перегляд</translation>
     </message>
     <message>
         <source>Open</source>
+        <translation>Відкрити</translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;i&gt;Alternate spellings (accents suppressed): &lt;/i&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Write to File</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Preview P&amp;arent document/folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Open Parent document/folder</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1052,7 +1095,7 @@ Do you want to start the  preferences dialog ?</source>
     </message>
     <message>
         <source>Choose search type.</source>
-        <translation type="unfinished"></translation>
+        <translation>Оберіть тип пошуку.</translation>
     </message>
 </context>
 <context>
@@ -1643,26 +1686,30 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Highlight color for query terms</source>
-        <translation type="unfinished"></translation>
+        <translation>Колір виділення ключових слів</translation>
     </message>
     <message>
         <source>Deactivate All</source>
-        <translation type="unfinished"></translation>
+        <translation>Виключити все</translation>
     </message>
     <message>
         <source>Prefer Html to plain text for preview.</source>
-        <translation type="unfinished"></translation>
+        <translation>Віддавати перевагу HTML над текстом для перегляду.</translation>
     </message>
     <message>
         <source>If checked, results with the same content under different names will only be shown once.</source>
-        <translation type="unfinished"></translation>
+        <translation>Якщо увімкнене, результати с таким самим змістом та різними назвами буде показано не більше одного разу.</translation>
     </message>
     <message>
         <source>Hide duplicate results.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ховати дублікати</translation>
     </message>
     <message>
         <source>Choose editor applications</source>
+        <translation>Оберіть редактори</translation>
+    </message>
+    <message>
+        <source>Display category filter as toolbar instead of button panel (needs restart).</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1701,6 +1748,10 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Select one or several mime types then click &quot;Change Action&quot;</source>
+        <translation type="obsolete">Виділіть один чи декілька MIME-типів та натисніть &quot;Змінити дію&quot;</translation>
+    </message>
+    <message>
+        <source>Select one or several mime types then click &quot;Change Action&quot;&lt;br&gt;You can also close this dialog and check &quot;Use desktop preferences&quot;&lt;br&gt;in the main panel to ignore this list and use your desktop defaults.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1787,6 +1838,33 @@ This should give higher precedence to the results where the search terms appear
         <translation type="obsolete">Неможна виконати суцільно негативний запит.  Будь ласка, введіть загальні терміни у полі &quot;будь-які слова&quot;</translation>
     </message>
 </context>
+<context>
+    <name>confgui::ConfBeaglePanelW</name>
+    <message>
+        <source>Steal Beagle indexing queue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Beagle MUST NOT be running. Enables processing the beagle queue to index Firefox web history.&lt;br&gt;(you should also install the Firefox Beagle plugin)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Web cache directory name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The name for a directory where to store the cache for visited web pages.&lt;br&gt;A non-absolute path is taken relative to the configuration directory.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. size for the web cache (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Entries will be recycled once the size is reached</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>confgui::ConfIndexW</name>
     <message>
@@ -1820,10 +1898,37 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>Max. compressed file size (KB)</source>
-        <translation type="unfinished"></translation>
+        <translation>Межа розміру стиснених файлів (KB)</translation>
     </message>
     <message>
         <source>This value sets a threshold beyond which compressedfiles will not be processed. Set to -1 for no limit, to 0 for no decompression ever.</source>
+        <translation>Це значення встановлює поріг розміру стиснених файлів, більші за нього не буде опрацьовано.  -1 вимикає ліміт, 0 вимикає декомпресію.</translation>
+    </message>
+    <message>
+        <source>Max. text file size (MB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This value sets a threshold beyond which text files will not be processed. Set to -1 for no limit. 
+This is for excluding monster log files from the index.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text file page size (KB)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this value is set (not equal to -1), text files will be split in chunks of this size for indexing.
+This will help searching very big text  files (ie: log files).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Max. filter exec. time (S)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>External filters working longer than this will be aborted. This is for the rare case (ie: postscript) where a document could cause a filter to loopSet to -1 for no limit.
+</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1919,15 +2024,15 @@ This should give higher precedence to the results where the search terms appear
     </message>
     <message>
         <source>These are names of directories which indexing will not enter.&lt;br&gt; May contain wildcards. Must match the paths seen by the indexer (ie: if topdirs includes &apos;/home/me&apos; and &apos;/home&apos; is actually a link to &apos;/usr/home&apos;, a correct skippedPath entry would be &apos;/home/me/tmp*&apos;, not &apos;/usr/home/me/tmp*&apos;)</source>
-        <translation type="unfinished"></translation>
+        <translation>Це назви тек, у які індексування не потрапить.&lt;br&gt; Може містити шаблони.  Має співпадати із шляхами, що бачить індексатор (наприклад, якщо topdirs містить  &apos;/home/me&apos; та &apos;/home&apos; є посиланням на &apos;/usr/home&apos;, то вірний запис буде &apos;/home/me/tmp*&apos;, а не &apos;/usr/home/me/tmp*&apos;)</translation>
     </message>
     <message>
         <source>This value adjust the amount of data which is indexed between flushes to disk.&lt;br&gt;This helps control the indexer memory usage. Default 10MB </source>
-        <translation type="unfinished"></translation>
+        <translation>Скільки даних буде проіндексовано між скиданнями індексу на диск.&lt;br&gt;Допомагає контролювати використання пам&apos;яті індексатором. Типово: 10Мб </translation>
     </message>
     <message>
         <source>Disables use of aspell to generate spelling approximation in the term explorer tool.&lt;br&gt; Useful if aspell is absent or does not work. </source>
-        <translation type="unfinished"></translation>
+        <translation>Вимикає використання aspell для генерації наближень у написання в навіґаторі термінів.&lt;br&gt;Корисне, коли aspell відсутній або зламаний. </translation>
     </message>
 </context>
 </TS>
