@@ -20,6 +20,7 @@
 
 #include <qvariant.h>
 #include <qwidget.h>
+#include <stdio.h>
 
 #include "rcldb.h"
 #include "refcntr.h"
@@ -47,37 +48,47 @@ class Q3PopupMenu;
 #define QTEXTEDIT Q3TextEdit
 #endif
 
-class PreviewTextEdit : public QTEXTEDIT {
-    Q_OBJECT
-public:
-    PreviewTextEdit(QWidget* parent, const char* name, Preview *pv) 
-	: QTEXTEDIT(parent, name), m_preview(pv)
-    {}
-    void moveToAnchor(const QString& name);
-public slots:
-    virtual void menuToggleFields();
-private:
-    virtual RCLPOPUP *createPopupMenu(const QPoint& pos);
-    Preview *m_preview;
-    QString  m_savedText;
-};
-
-
 // We keep a list of data associated to each tab
 class TabData {
- public:
-    string fn; // filename for this tab
+public:
+    string url; // filename for this tab
     string ipath; // Internal doc path inside file
-    QWidget *w; // widget for setCurrent
     int docnum;  // Index of doc in db search results.
     // doc out of internfile (previous fields come from the index) with
     // main text erased (for space).
     Rcl::Doc fdoc; 
-    TabData(QWidget *wi) 
-	: w(wi), docnum(-1) 
+    // Saved rich text: the textedit seems to sometimes (but not
+    // always) return its text stripped of tags, so this is needed
+    // (for printing for example)
+    QString  richtxt; 
+    TabData() 
+	: docnum(-1) 
     {}
 };
 
+class PreviewTextEdit : public QTEXTEDIT {
+    Q_OBJECT
+public:
+    PreviewTextEdit(QWidget* parent, const char* name, Preview *pv) 
+	: QTEXTEDIT(parent, name), m_preview(pv), m_dspflds(false)
+    {}
+    void moveToAnchor(const QString& name);
+#if (QT_VERSION >= 0x040000)
+    virtual bool find(const QString &expr, bool cs, bool wo,bool forward = true,
+                      int *para = 0, int *index = 0);
+#endif
+public slots:
+    virtual void toggleFields();
+    virtual void print();
+    friend class Preview;
+private:
+    virtual RCLPOPUP *createPopupMenu(const QPoint& pos);
+    Preview *m_preview;
+    TabData  m_data;
+    bool     m_dspflds;
+};
+
+
 // Subclass plainToRich to add <termtag>s and anchors to the preview text
 class PlainToRichQtPreview : public PlainToRich {
 public:
@@ -91,7 +102,7 @@ public:
 	if (m_inputhtml) {
 	    return snull;
 	} else {
-	    return string("<qt><head><title></title></head><body><p>");
+	    return string("<qt><head><title></title></head><body><pre>");
 	}
     }
     virtual string startMatch() {return string("<termtag>");}
@@ -108,6 +119,10 @@ public:
     virtual string startAnchor(int i) {
 	return string("<a name=\"") + termAnchorName(i) + "\">";
     }
+    virtual string endAnchor() {
+	return string("</a>");
+    }
+    virtual string startChunk() { return "<pre>";}
 };
 
 class Preview : public QWidget {
@@ -126,8 +141,13 @@ public:
 
     virtual void closeEvent(QCloseEvent *e );
     virtual bool eventFilter(QObject *target, QEvent *event );
-    virtual bool makeDocCurrent(const string &fn, size_t sz, 
-				const Rcl::Doc& idoc, int docnum, 
+    /** 
+     * Arrange for the document to be displayed either by exposing the tab 
+     * if already loaded, or by creating a new tab and loading it.
+     * @para docnum is used to link back to the result list (to highlight 
+     *   paragraph when tab exposed etc.
+     */
+    virtual bool makeDocCurrent(const Rcl::Doc& idoc, int docnum, 
 				bool sametab = false);
     friend class PreviewTextEdit;
 public slots:
@@ -147,6 +167,7 @@ signals:
     void showNext(Preview *w, int sid, int docnum);
     void showPrev(Preview *w, int sid, int docnum);
     void previewExposed(Preview *w, int sid, int docnum);
+    void printCurrentPreviewRequest();
 
 private:
     // Identifier of search in main window. This is used to check that
@@ -157,7 +178,6 @@ private:
     bool          m_dynSearchActive;
     bool          m_canBeep;
     bool          m_loading;
-    list<TabData> m_tabData;
     QWidget      *m_currentW;
     HiliteData    m_hData;
     bool          m_justCreated; // First tab create is different
@@ -175,14 +195,10 @@ private:
     QCheckBox* matchCheck;
 
     void init();
-    virtual void setCurTabProps(const string& fn, const Rcl::Doc& doc, 
-				int docnum);
-    virtual PreviewTextEdit *getCurrentEditor();
+    virtual void setCurTabProps(const Rcl::Doc& doc, int docnum);
+    virtual PreviewTextEdit *currentEditor();
     virtual PreviewTextEdit *addEditorTab();
-    virtual bool loadFileInCurrentTab(string fn, size_t sz, 
-				      const Rcl::Doc& idoc, int dnm);
-    // Return auxiliary data pointer for cur tab
-    TabData *tabDataForCurrent(); 
+    virtual bool loadDocInCurrentTab(const Rcl::Doc& idoc, int dnm);
 };
 
 #endif /* _PREVIEW_W_H_INCLUDED_ */
