@@ -70,6 +70,7 @@ public:
 	init();
     }
     ~RclMain() {}
+    virtual bool eventFilter(QObject *target, QEvent *event);
 
 public slots:
     virtual bool close();
@@ -109,6 +110,7 @@ public slots:
     // Prefs menu about to show, set the checked lang entry
     virtual void adjustPrefsMenu();
     virtual void catgFilter(int);
+    virtual void initDbOpen();
 
 signals:
     void stemLangChanged(const QString& lang);
@@ -123,6 +125,7 @@ private:
     UIPrefsDialog  *uiprefs;
     ConfIndexW     *indexConfig;
     SpellW         *spellform;
+    QTimer         *periodictimer;
 
     vector<TempFile>  m_tempfiles;
     map<QString, int> m_stemLangToId;
