@@ -104,6 +104,8 @@ class DocSequence {
 	return doc.meta[Rcl::Doc::keyabs];
     }
 
+    virtual bool getEnclosing(Rcl::Doc&, Rcl::Doc&) {return false;}
+
     /** Get estimated total count in results */
     virtual int getResCnt() = 0;
 
@@ -121,6 +123,11 @@ class DocSequence {
     {
 	terms.clear(); groups.clear(); gslks.clear(); return true;
     }
+    /** Get user-input terms (before stemming etc.) */
+    virtual void getUTerms(vector<string>& terms)
+    {
+	terms.clear(); 
+    }
     virtual list<string> expand(Rcl::Doc &) {return list<string>();}
 
     /** Optional functionality. Yeah, not nice */
@@ -157,6 +164,10 @@ public:
     {
 	return m_seq->getTerms(terms, groups, gslks);
     }
+    virtual void getUTerms(vector<string>& terms)
+    {
+	m_seq->getUTerms(terms);
+    }
 
 protected:
     RefCntr<DocSequence>    m_seq;
