@@ -43,14 +43,8 @@ using namespace std;
 #include "wipedir.h"
 #include "transcode.h"
 
-bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& doc)
+bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& idoc)
 {
-    string fn = doc.url.substr(7);
-    struct stat st;
-    if (stat(fn.c_str(), &st) != 0) {
-	cout << "No such file: " << fn << endl;
-	return true;
-    } 
     if (tmpdir.empty() || access(tmpdir.c_str(), 0) < 0) {
 	string reason;
 	if (!maketmpdir(tmpdir, reason)) {
@@ -60,11 +54,14 @@ bool dump_contents(RclConfig *rclconfig, string& tmpdir, Rcl::Doc& doc)
 	}
     }
     wipedir(tmpdir);
-    FileInterner interner(fn, &st, rclconfig, tmpdir, &doc.mimetype);
-    if (interner.internfile(doc, doc.ipath)) {
-	cout << doc.text << endl;
+    FileInterner interner(idoc, rclconfig, tmpdir, 
+                          FileInterner::FIF_forPreview);
+    Rcl::Doc fdoc;
+    string ipath = idoc.ipath;
+    if (interner.internfile(fdoc, ipath)) {
+	cout << fdoc.text << endl;
     } else {
-	cout << "Cant intern: " << fn << endl;
+	cout << "Cant turn to text:" << idoc.url << " | " << idoc.ipath << endl;
     }
     return true;
 }
@@ -74,7 +71,7 @@ static char *thisprog;
 static char usage [] =
 " [-o|-a|-f] <query string>\n"
 " Runs a recoll query and displays result lines. \n"
-"  Default: will interpret the argument(s) as a wasabi query string\n"
+"  Default: will interpret the argument(s) as a xesam query string\n"
 "    query may be like: \n"
 "    implicit AND, Exclusion, field spec:    t1 -t2 title:t3\n"
 "    OR has priority: t1 OR t2 t3 OR t4 means (t1 OR t2) AND (t3 OR t4)\n"
@@ -114,12 +111,13 @@ static int     op_flags;
 #define OPT_m     0x800
 #define OPT_D     0x1000
 #define OPT_S     0x2000
-
+#define OPT_s     0x4000
 
 int recollq(RclConfig **cfp, int argc, char **argv)
 {
     string a_config;
     string sortfield;
+    string stemlang("english");
 
     int limit = 2000;
     thisprog = argv[0];
@@ -151,6 +149,9 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	    case 'S':	op_flags |= OPT_S; if (argc < 2)  Usage();
 		sortfield = *(++argv);
 		argc--; goto b1;
+	    case 's':	op_flags |= OPT_s; if (argc < 2)  Usage();
+		stemlang = *(++argv);
+		argc--; goto b1;
             case 't':   op_flags |= OPT_t; break;
             default: Usage();   break;
             }
@@ -223,7 +224,7 @@ int recollq(RclConfig **cfp, int argc, char **argv)
 	cerr << "Query string interpretation failed: " << reason << endl;
 	return 1;
     }
-    sd->setStemlang("english");
+    sd->setStemlang(stemlang);
 
     RefCntr<Rcl::SearchData> rq(sd);
     Rcl::Query query(&rcldb);
