@@ -31,6 +31,20 @@ enum value_slot {
     MSG = "Caught unknown xapian exception";	   \
  } 
 
+#define XAPTRY(STMTTOTRY, XAPDB, ERSTR)       \
+    for (int tries = 0; tries < 2; tries++) { \
+	try {                                 \
+            STMTTOTRY;                        \
+            ERSTR.erase();                    \
+            break;                            \
+	} catch (const Xapian::DatabaseModifiedError &e) { \
+            ERSTR = e.get_msg();                           \
+	    XAPDB.reopen();                                \
+            continue;                                      \
+	} XCATCHERROR(ERSTR);                              \
+        break;                                             \
+    }
+
 class Query;
 
 // A class for data and methods that would have to expose
@@ -39,18 +53,23 @@ class Query;
 // common.
 class Db::Native {
  public:
-    Db  *m_db;
+    Db  *m_rcldb; // Parent
     bool m_isopen;
     bool m_iswritable;
     bool m_noversionwrite; //Set if open failed because of version mismatch!
-    // Indexing
-    Xapian::WritableDatabase wdb;
 
-    // Querying
-    Xapian::Database db;
-    
+    // Indexing 
+    Xapian::WritableDatabase xwdb;
+    // Querying (active even if the wdb is too)
+    Xapian::Database xrdb;
+
+    // We sometimes go through the wdb for some query ops, don't
+    // really know if this makes sense
+    Xapian::Database& xdb() {return m_iswritable ? xwdb : xrdb;}
+
     Native(Db *db) 
-	: m_db(db), m_isopen(false), m_iswritable(false),m_noversionwrite(false)
+	: m_rcldb(db), m_isopen(false), m_iswritable(false),
+          m_noversionwrite(false)
     { }
 
     ~Native() {
