@@ -22,6 +22,7 @@ static char rcsid[] = "@(#$Id: searchdata.cpp,v 1.32 2008-12-19 09:55:36 dockes
 
 #include <string>
 #include <vector>
+#include <algorithm>
 
 #include "xapian.h"
 
@@ -173,6 +174,15 @@ bool SearchData::getTerms(vector<string>& terms,
 	(*it)->getTerms(terms, groups, gslks);
     return true;
 }
+// Extract user terms
+void SearchData::getUTerms(vector<string>& terms) const
+{
+    for (qlist_cit_t it = m_query.begin(); it != m_query.end(); it++)
+	(*it)->getUTerms(terms);
+    sort(terms.begin(), terms.end());
+    vector<string>::iterator it = unique(terms.begin(), terms.end());
+    terms.erase(it, terms.end());
+}
 
 // Splitter callback for breaking a user string into simple terms and
 // phrases. This is for parts of the user entry which would appear as
@@ -230,9 +240,9 @@ class wsQData : public TextSplitCB {
 // translating.
 class StringToXapianQ {
 public:
-    StringToXapianQ(Db& db, const string& prefix, 
+    StringToXapianQ(Db& db, const string& field, 
 		    const string &stmlng, bool boostUser)
-	: m_db(db), m_prefix(prefix), m_stemlang(stmlng), 
+	: m_db(db), m_field(field), m_stemlang(stmlng), 
 	  m_doBoostUserTerms(boostUser)
     { }
 
@@ -249,10 +259,15 @@ public:
 	groups.insert(groups.end(), m_groups.begin(), m_groups.end());
 	return true;
     }
+    bool getUTerms(vector<string>& terms) 
+    {
+	terms.insert(terms.end(), m_uterms.begin(), m_uterms.end());
+	return true;
+    }
 
 private:
     void expandTerm(bool dont, const string& term, list<string>& exp, 
-		      string& sterm);
+                    string& sterm, string *prefix = 0);
     // After splitting entry on whitespace: process non-phrase element
     void processSimpleSpan(const string& span, bool nostemexp, list<Xapian::Query> &pqueries);
     // Process phrase/near element
@@ -261,14 +276,26 @@ private:
 			     bool useNear, int slack);
 
     Db&           m_db;
-    const string& m_prefix;
+    const string& m_field;
     const string& m_stemlang;
     bool          m_doBoostUserTerms;
     // Single terms and phrases resulting from breaking up text;
+    vector<string>          m_uterms;
     vector<string>          m_terms;
     vector<vector<string> > m_groups; 
 };
 
+#if 0
+static void listVector(const string& what, const vector<string>&l)
+{
+    string a;
+    for (vector<string>::const_iterator it = l.begin(); it != l.end(); it++) {
+        a = a + *it + " ";
+    }
+    LOGDEB(("%s: %s\n", what.c_str(), a.c_str()));
+}
+#endif
+
 /** Expand stem and wildcards
  *
  * @param nostemexp don't perform stem expansion. This is mainly used to
@@ -282,12 +309,12 @@ private:
  * @param sterm output original input term if there were no wildcards
  */
 void StringToXapianQ::expandTerm(bool nostemexp, 
-				      const string& term, 
-				      list<string>& exp,
-				      string &sterm)
+                                 const string& term, 
+                                 list<string>& exp,
+                                 string &sterm, string *prefix)
 {
-    LOGDEB2(("expandTerm: term [%s] stemlang [%s] nostemexp %d\n", 
-	     term.c_str(), m_stemlang.c_str(), nostemexp));
+    LOGDEB2(("expandTerm: field [%s] term [%s] stemlang [%s] nostemexp %d\n", 
+             m_field.c_str(), term.c_str(), m_stemlang.c_str(), nostemexp));
     sterm.erase();
     exp.clear();
     if (term.empty()) {
@@ -300,27 +327,34 @@ void StringToXapianQ::expandTerm(bool nostemexp,
     if (haswild || m_stemlang.empty())
 	nostemexp = true;
 
-    if (!nostemexp) {
-    }
-
     if (nostemexp && !haswild) {
 	// Neither stemming nor wildcard expansion: just the word
+        string pfx;
+        if (!m_field.empty())
+            m_db.fieldToPrefix(m_field, pfx);
 	sterm = term;
-	exp.push_front(term);
+        m_uterms.push_back(sterm);
+	exp.push_front(pfx+term);
 	exp.resize(1);
+        if (prefix)
+            *prefix = pfx;
     } else {
 	list<TermMatchEntry> l;
 	if (haswild) {
-	    m_db.termMatch(Rcl::Db::ET_WILD, m_stemlang, term, l);
+	    m_db.termMatch(Rcl::Db::ET_WILD, m_stemlang, term, l, -1, m_field,
+                           prefix);
 	} else {
 	    sterm = term;
-	    m_db.termMatch(Rcl::Db::ET_STEM, m_stemlang, term, l);
+            m_uterms.push_back(sterm);
+	    m_db.termMatch(Rcl::Db::ET_STEM, m_stemlang, term, l, -1, m_field,
+                           prefix);
 	}
 	for (list<TermMatchEntry>::const_iterator it = l.begin(); 
 	     it != l.end(); it++) {
 	    exp.push_back(it->term);
 	}
     }
+    //listVector("ExpandTerm:uterms now: ", m_uterms);
 }
 
 // Do distribution of string vectors: a,b c,d -> a,c a,d b,c b,d
@@ -357,23 +391,14 @@ void multiply_groups(vector<vector<string> >::const_iterator vvit,
     }
 }
 
-/** Add prefix to all strings in list */
-static void addPrefix(list<string>& terms, const string& prefix)
-{
-    if (prefix.empty())
-	return;
-    for (list<string>::iterator it = terms.begin(); it != terms.end(); it++)
-	it->insert(0, prefix);
-}
-
 void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
 					list<Xapian::Query> &pqueries)
 {
     list<string> exp;  
     string sterm; // dumb version of user term
-    expandTerm(nostemexp, span, exp, sterm);
+    string prefix;
+    expandTerm(nostemexp, span, exp, sterm, &prefix);
     m_terms.insert(m_terms.end(), exp.begin(), exp.end());
-    addPrefix(exp, m_prefix);
     // Push either term or OR of stem-expanded set
     Xapian::Query xq(Xapian::Query::OP_OR, exp.begin(), exp.end());
 
@@ -383,10 +408,10 @@ void StringToXapianQ::processSimpleSpan(const string& span, bool nostemexp,
     // less wqf). This does not happen if there are wildcards anywhere
     // in the search.
     if (m_doBoostUserTerms && !sterm.empty()) {
-	xq = Xapian::Query(Xapian::Query::OP_OR, 
-			   xq, 
-			   Xapian::Query(m_prefix+sterm, 
-					 original_term_wqf_booster));
+        xq = Xapian::Query(Xapian::Query::OP_OR, 
+                           xq, 
+                           Xapian::Query(prefix+sterm, 
+                                         original_term_wqf_booster));
     }
     pqueries.push_back(xq);
 }
@@ -418,7 +443,6 @@ void StringToXapianQ::processPhraseOrNear(wsQData *splitData,
 	list<string>exp;
 	expandTerm(nostemexp, *it, exp, sterm);
 	groups.push_back(vector<string>(exp.begin(), exp.end()));
-	addPrefix(exp, m_prefix);
 	orqueries.push_back(Xapian::Query(Xapian::Query::OP_OR, 
 					  exp.begin(), exp.end()));
 #ifdef XAPIAN_NEAR_EXPAND_SINGLE_BUF
@@ -468,6 +492,7 @@ bool StringToXapianQ::processUserString(const string &iq,
 {
     LOGDEB(("StringToXapianQ:: query string: [%s]\n", iq.c_str()));
     ermsg.erase();
+    m_uterms.clear();
     m_terms.clear();
     m_groups.clear();
 
@@ -569,9 +594,6 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
 	LOGERR(("SearchDataClauseSimple: bad m_tp %d\n", m_tp));
 	return false;
     }
-    string prefix;
-    if (!m_field.empty())
-	db.fieldToPrefix(m_field, prefix);
     list<Xapian::Query> pqueries;
 
     // We normally boost the original term in the stem expansion list. Don't
@@ -580,7 +602,7 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
 	(m_parentSearch && !m_parentSearch->haveWildCards()) || 
 	(m_parentSearch == 0 && !m_haveWildCards);
 
-    StringToXapianQ tr(db, prefix, l_stemlang, doBoostUserTerm);
+    StringToXapianQ tr(db, m_field, l_stemlang, doBoostUserTerm);
     if (!tr.processUserString(m_text, m_reason, pqueries, 
 			      db.getStopList()))
 	return false;
@@ -589,11 +611,14 @@ bool SearchDataClauseSimple::toNativeQuery(Rcl::Db &db, void *p,
 	return false;
     }
     tr.getTerms(m_terms, m_groups);
+    tr.getUTerms(m_uterms);
+    //listVector("SearchDataClauseSimple: Uterms: ", m_uterms);
     *qp = Xapian::Query(op, pqueries.begin(), pqueries.end());
     return true;
 }
 
-// Translate a FILENAME search clause. 
+// Translate a FILENAME search clause. Actually this is now mostly
+// a "filename" field search.
 bool SearchDataClauseFilename::toNativeQuery(Rcl::Db &db, void *p, 
 					     const string&)
 {
@@ -630,10 +655,6 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
     list<Xapian::Query> pqueries;
     Xapian::Query nq;
 
-    string prefix;
-    if (!m_field.empty())
-	db.fieldToPrefix(m_field, prefix);
-
     // We normally boost the original term in the stem expansion list. Don't
     // do it if there are wildcards anywhere, this would skew the results.
     bool doBoostUserTerm = 
@@ -650,7 +671,7 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
     }
     string s = string("\"") + m_text + string("\"");
     bool useNear = (m_tp == SCLT_NEAR);
-    StringToXapianQ tr(db, prefix, l_stemlang, doBoostUserTerm);
+    StringToXapianQ tr(db, m_field, l_stemlang, doBoostUserTerm);
     if (!tr.processUserString(s, m_reason, pqueries, db.getStopList(),
 			      m_slack, useNear))
 	return false;
@@ -659,6 +680,7 @@ bool SearchDataClauseDist::toNativeQuery(Rcl::Db &db, void *p,
 	return true;
     }
     tr.getTerms(m_terms, m_groups);
+    tr.getUTerms(m_uterms);
     *qp = *pqueries.begin();
     return true;
 }
@@ -675,5 +697,9 @@ bool SearchDataClauseSub::getTerms(vector<string>& terms,
 {
     return m_sub.getconstptr()->getTerms(terms, groups, gslks);
 }
+void SearchDataClauseSub::getUTerms(vector<string>& terms) const
+{
+    m_sub.getconstptr()->getUTerms(terms);
+}
 
 } // Namespace Rcl
