@@ -17,7 +17,7 @@
 #ifndef _EXECMD_H_INCLUDED_
 #define _EXECMD_H_INCLUDED_
 /* @(#$Id: execmd.h,v 1.12 2007-05-21 13:30:22 dockes Exp $  (C) 2004 J.F.Dockes */
-
+#include <signal.h>
 #include <string>
 #include <list>
 #include <vector>
@@ -27,15 +27,26 @@ using std::string;
 using std::vector;
 #endif
 
-/** Callback function object to advise of new data arrival (or just heartbeat)  * if cnt is 0 */
+#include "netcon.h"
+
+/** 
+ * Callback function object to advise of new data arrival, or just periodic 
+ * heartbeat if cnt is 0. 
+ *
+ * To interrupt the command, the code using ExecCmd should either
+ * raise an exception inside newData() (and catch it in doexec's caller), or 
+ * call ExecCmd::setKill() 
+ * 
+ */
 class ExecCmdAdvise {
  public:
     virtual ~ExecCmdAdvise() {}
     virtual void newData(int cnt) = 0;
 };
 
-/** Callback function object to get more input data. Data has to be provided
- *  in the initial input string, set it to empty to signify eof
+/** 
+ * Callback function object to get more input data. Data has to be provided
+ * in the initial input string, set it to empty to signify eof.
  */
 class ExecCmdProvide {
  public:
@@ -63,6 +74,38 @@ class ExecCmdProvide {
  */
 class ExecCmd {
  public:
+    /** 
+     * Add/replace environment variable before executing command. This must
+     * be called before doexec() to have an effect (possibly multiple
+     * times for several variables).
+     * @param envassign an environment assignment string ("name=value")
+     */
+    void putenv(const string &envassign);
+
+    /** 
+     * Set function objects to call whenever new data is available or on
+     * select timeout / whenever new data is needed to send. Must be called
+     * before doexec()
+     */
+    void setAdvise(ExecCmdAdvise *adv) {m_advise = adv;}
+    void setProvide(ExecCmdProvide *p) {m_provide = p;}
+
+    /**
+     * Set select timeout in milliseconds. The default is 1 S. 
+     * This is NOT a time after which an error will occur, but the period of
+     * the calls to the cancellation check routine.
+     */
+    void setTimeout(int mS) {if (mS > 30) m_timeoutMs = mS;}
+
+    /** 
+     * Set destination for stderr data. The default is to let it alone (will 
+     * usually go to the terminal or to wherever the desktop messages go).
+     * There is currently no option to put stderr data into a program variable
+     * If the parameter can't be opened for writing, the command's
+     * stderr will be closed.
+     */
+    void setStderr(const string &stderrFile) {m_stderrFile = stderrFile;}
+
     /**
      * Execute command. 
      *
@@ -83,45 +126,33 @@ class ExecCmd {
     int doexec(const string &cmd, const list<string>& args, 
 	       const string *input = 0, 
 	       string *output = 0);
-    /** 
-     * Add/replace environment variable before executing command. This must
-     * be called before doexec to have an effect (possibly multiple
-     * times for several variables).
-     * @param envassign an environment assignment string (name=value)
-     */
-    void putenv(const string &envassign);
 
-    /** 
-     * Set function objects to call whenever new data is available or on
-     * select timeout / whenever new data is needed to send.
+    /*
+     * The next four methods can be used when a Q/A dialog needs to be 
+     * performed with the command
      */
-    void setAdvise(ExecCmdAdvise *adv) {m_advise = adv;}
-    void setProvide(ExecCmdProvide *p) {m_provide = p;}
+    int startExec(const string &cmd, const list<string>& args, 
+		  bool has_input, bool has_output);
+    int send(const string& data);
+    int receive(string& data, int cnt = -1);
+    int getline(string& data);
+    int wait(bool haderror = false);
 
-    /**
-     * Set select timeout in milliseconds. The default is 1 S. 
-     */
-    void setTimeout(int mS) {if (mS > 30) m_timeoutMs = mS;}
-
-    /** 
-     * Set destination for stderr data. The default is to let it alone (will 
-     * usually go to the terminal or to wherever the desktop messages go).
-     * There is currently no option to put stderr data into a program variable
-     * If the parameter can't be opened for writing, the command's
-     * stderr will be closed.
-     */
-    void setStderr(const string &stderrFile) {m_stderrFile = stderrFile;}
+    pid_t getChildPid() {return m_pid;}
 
     /** 
      * Cancel/kill command. This can be called from another thread or
      * from the advise callback, which could also raise an exception to 
      * accomplish the same thing
      */
-    void setCancel() {m_cancelRequest = true;}
+    void setKill() {m_killRequest = true;}
 
     ExecCmd() 
-	: m_advise(0), m_provide(0), m_cancelRequest(false), m_timeoutMs(1000)
-	{}
+	: m_advise(0), m_provide(0), m_timeoutMs(1000)
+    {
+	reset();
+    }
+    ~ExecCmd();
 
     /**
      * Utility routine: check if/where a command is found according to the
@@ -131,16 +162,38 @@ class ExecCmd {
      * @param path exec seach path to use instead of getenv(PATH)
      * @return true if found
      */
-    static bool which(const string& cmd, string& exepath, 
-		      const char* path = 0);
+    static bool which(const string& cmd, string& exe, const char* path = 0);
 
+    friend class ExecCmdRsrc;
  private:
     vector<string>   m_env;
     ExecCmdAdvise   *m_advise;
     ExecCmdProvide  *m_provide;
-    bool             m_cancelRequest;
+    bool             m_killRequest;
     int              m_timeoutMs;
     string           m_stderrFile;
+    // Pipe for data going to the command
+    int              m_pipein[2];
+    NetconP          m_tocmd;
+    // Pipe for data coming out
+    int              m_pipeout[2];
+    NetconP          m_fromcmd;
+    // Subprocess id
+    pid_t            m_pid;
+    // Saved sigmask
+    sigset_t         m_blkcld;
+
+    // Reset internal state indicators. Any resources should have been
+    // previously freed
+    void reset() {
+	m_killRequest = false;
+	m_pipein[0] = m_pipein[1] = m_pipeout[0] = m_pipeout[1] = -1;
+	m_pid = -1;
+	sigemptyset(&m_blkcld);
+    }
+    // Child process code
+    void dochild(const string &cmd, const list<string>& args, 
+		 bool has_input, bool has_output);
 };
 
 
